@@ -11,11 +11,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'BASECFLAGS': '-Wno-unused-result -Werror=declaration-after-statement',
+ 'BASECFLAGS': '-Wno-unused-result',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/lib/python-3.4.0/bin',
- 'BINLIBDEST': '/opt/lib/python-3.4.0/lib/python3.4',
+ 'BINDIR': '/opt/lib/python-3.4.2/bin',
+ 'BINLIBDEST': '/opt/lib/python-3.4.2/lib/python3.4',
  'BLDLIBRARY': 'libpython3.4m.a',
  'BLDSHARED': 'gcc -pthread -shared',
  'BUILDEXE': '',
@@ -24,33 +24,35 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement -DNDEBUG '
-           '-g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall '
+           '-Wstrict-prototypes',
  'CFLAGSFORSHARED': '',
+ 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.4.0' '--enable-ipv6' "
+ 'CONFIG_ARGS': "'--prefix=/opt/lib/python-3.4.2' '--enable-ipv6' "
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb' '--with-wide-unicode' "
                 "'--with-computed-gotos' '--with-pymalloc'",
- 'CONFINCLUDEDIR': '/opt/lib/python-3.4.0/include',
- 'CONFINCLUDEPY': '/opt/lib/python-3.4.0/include/python3.4m',
+ 'CONFINCLUDEDIR': '/opt/lib/python-3.4.2/include',
+ 'CONFINCLUDEPY': '/opt/lib/python-3.4.2/include/python3.4m',
  'COREPYTHONPATH': ':plat-linux',
- 'COVERAGE_INFO': '/home/sources/packages/Python-3.4.0/coverage.info',
- 'COVERAGE_REPORT': '/home/sources/packages/Python-3.4.0/lcov-report',
+ 'COVERAGE_INFO': '/home/sources/packages/Python-3.4.2/coverage.info',
+ 'COVERAGE_REPORT': '/home/sources/packages/Python-3.4.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -IInclude -I./Include',
  'CXX': 'g++ -pthread',
- 'DESTDIRS': '/opt/lib/python-3.4.0 /opt/lib/python-3.4.0/lib '
-             '/opt/lib/python-3.4.0/lib/python3.4 '
-             '/opt/lib/python-3.4.0/lib/python3.4/lib-dynload',
- 'DESTLIB': '/opt/lib/python-3.4.0/lib/python3.4',
+ 'DESTDIRS': '/opt/lib/python-3.4.2 /opt/lib/python-3.4.2/lib '
+             '/opt/lib/python-3.4.2/lib/python3.4 '
+             '/opt/lib/python-3.4.2/lib/python3.4/lib-dynload',
+ 'DESTLIB': '/opt/lib/python-3.4.2/lib/python3.4',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/lib/python-3.4.0/lib/python3.4/lib-dynload',
+ 'DESTSHARED': '/opt/lib/python-3.4.2/lib/python3.4/lib-dynload',
  'DIRMODE': 755,
  'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
          'Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -449,12 +451,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'x86_64-unknown-linux-gnu',
- 'INCLDIRSTOMAKE': '/opt/lib/python-3.4.0/include '
-                   '/opt/lib/python-3.4.0/include '
-                   '/opt/lib/python-3.4.0/include/python3.4m '
-                   '/opt/lib/python-3.4.0/include/python3.4m',
- 'INCLUDEDIR': '/opt/lib/python-3.4.0/include',
- 'INCLUDEPY': '/opt/lib/python-3.4.0/include/python3.4m',
+ 'INCLDIRSTOMAKE': '/opt/lib/python-3.4.2/include '
+                   '/opt/lib/python-3.4.2/include '
+                   '/opt/lib/python-3.4.2/include/python3.4m '
+                   '/opt/lib/python-3.4.2/include/python3.4m',
+ 'INCLUDEDIR': '/opt/lib/python-3.4.2/include',
+ 'INCLUDEPY': '/opt/lib/python-3.4.2/include/python3.4m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
@@ -471,14 +473,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LDSHARED': 'gcc -pthread -shared',
  'LDVERSION': '3.4m',
  'LIBC': '',
- 'LIBDEST': '/opt/lib/python-3.4.0/lib/python3.4',
- 'LIBDIR': '/opt/lib/python-3.4.0/lib',
+ 'LIBDEST': '/opt/lib/python-3.4.2/lib/python3.4',
+ 'LIBDIR': '/opt/lib/python-3.4.2/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/lib/python-3.4.0/lib/pkgconfig',
- 'LIBPL': '/opt/lib/python-3.4.0/lib/python3.4/config-3.4m',
+ 'LIBPC': '/opt/lib/python-3.4.2/lib/pkgconfig',
+ 'LIBPL': '/opt/lib/python-3.4.2/lib/python3.4/config-3.4m',
  'LIBRARY': 'libpython3.4m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
@@ -494,18 +496,16 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEPPATH': ':plat-linux',
  'MACHDEPS': 'plat-linux @EXTRAPLATDIR@',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/lib/python-3.4.0/lib/python3.4',
+ 'MACHDESTLIB': '/opt/lib/python-3.4.2/lib/python3.4',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/lib/python-3.4.0/share/man',
+ 'MANDIR': '/opt/lib/python-3.4.2/share/man',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
  'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
-            'Modules/md5module.o  Modules/sha1module.o  '
-            'Modules/sha256module.o  Modules/sha512module.o  '
             'Modules/posixmodule.o  Modules/errnomodule.o  '
             'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
             'Modules/_weakref.o  Modules/_functoolsmodule.o  '
@@ -558,11 +558,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement '
-              '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Werror=declaration-after-statement '
-                   '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. '
-                   '-IInclude -I./Include  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall '
+              '-Wstrict-prototypes',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -DNDEBUG -g -fwrapv -O3 -Wall '
+                   '-Wstrict-prototypes -Werror=declaration-after-statement '
+                   '-I. -IInclude -I./Include  -DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-I. -IInclude -I./Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
@@ -576,7 +577,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': '',
- 'SCRIPTDIR': '/opt/lib/python-3.4.0/lib',
+ 'SCRIPTDIR': '/opt/lib/python-3.4.2/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
@@ -643,9 +644,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/sources/packages/Python-3.4.0',
- 'abs_srcdir': '/home/sources/packages/Python-3.4.0',
- 'datarootdir': '/opt/lib/python-3.4.0/share',
- 'exec_prefix': '/opt/lib/python-3.4.0',
- 'prefix': '/opt/lib/python-3.4.0',
+ 'abs_builddir': '/home/sources/packages/Python-3.4.2',
+ 'abs_srcdir': '/home/sources/packages/Python-3.4.2',
+ 'datarootdir': '/opt/lib/python-3.4.2/share',
+ 'exec_prefix': '/opt/lib/python-3.4.2',
+ 'prefix': '/opt/lib/python-3.4.2',
  'srcdir': '.'}
